DEBUG   |20240114 06:25:04|Fetching filter data from database
DEBUG   |20240114 06:25:04|Loading filters
DEBUG   |20240114 06:25:04|-- Loading filter Regexskipfiles
DEBUG   |20240114 06:25:04|-- Loading filter Multidb
DEBUG   |20240114 06:25:04|-- Loading filter Tables
DEBUG   |20240114 06:25:04|-- Loading filter Tabledata
DEBUG   |20240114 06:25:04|-- Loading filter Regexdirectories
DEBUG   |20240114 06:25:04|-- Loading filter Tablesalwaysskipped
DEBUG   |20240114 06:25:04|-- Loading filter Extradirs
DEBUG   |20240114 06:25:04|-- Loading filter Regexfiles
DEBUG   |20240114 06:25:04|-- Loading filter Regextabledata
DEBUG   |20240114 06:25:04|-- Loading filter Skipfiles
DEBUG   |20240114 06:25:04|-- Loading filter Regexskipdirs
DEBUG   |20240114 06:25:04|-- Loading filter Incremental
DEBUG   |20240114 06:25:04|-- Loading filter Regextables
DEBUG   |20240114 06:25:04|-- Loading filter Skipdirs
DEBUG   |20240114 06:25:04|-- Loading filter Files
DEBUG   |20240114 06:25:04|-- Loading filter Directories
DEBUG   |20240114 06:25:04|-- Loading filter Systemcachefiles
DEBUG   |20240114 06:25:04|-- Loading filter Excludetabledata
DEBUG   |20240114 06:25:04|-- Loading filter Excludefiles
DEBUG   |20240114 06:25:04|-- Loading filter Cvsfolders
DEBUG   |20240114 06:25:04|-- Loading filter Publicfolder
DEBUG   |20240114 06:25:04|-- Loading filter Joomlaskipfiles
DEBUG   |20240114 06:25:04|-- Loading filter Excludefolders
DEBUG   |20240114 06:25:04|-- Loading filter Siteroot
DEBUG   |20240114 06:25:04|-- Loading filter Libraries
DEBUG   |20240114 06:25:04|-- Loading filter Joomlaskipdirs
DEBUG   |20240114 06:25:04|-- Loading filter Sitedb
DEBUG   |20240114 06:25:04|Loading optional filters
DEBUG   |20240114 06:25:04|-- Loading optional filter Stack\StackHoststats
DEBUG   |20240114 06:25:04|-- Loading optional filter Stack\StackErrorlogs
DEBUG   |20240114 06:25:04|-- Loading optional filter Stack\StackActionlogs
DEBUG   |20240114 06:25:04|-- Loading optional filter Stack\StackFinder
DEBUG   |20260723 07:41:56|Fetching filter data from database
DEBUG   |20260723 07:41:56|Loading filters
DEBUG   |20260723 07:41:56|-- Loading filter Regexskipfiles
DEBUG   |20260723 07:41:56|-- Loading filter Multidb
DEBUG   |20260723 07:41:56|-- Loading filter Tables
DEBUG   |20260723 07:41:56|-- Loading filter Tabledata
DEBUG   |20260723 07:41:56|-- Loading filter Regexdirectories
DEBUG   |20260723 07:41:56|-- Loading filter Tablesalwaysskipped
DEBUG   |20260723 07:41:56|-- Loading filter Extradirs
DEBUG   |20260723 07:41:56|-- Loading filter Regexfiles
DEBUG   |20260723 07:41:56|-- Loading filter Regextabledata
DEBUG   |20260723 07:41:56|-- Loading filter Skipfiles
DEBUG   |20260723 07:41:56|-- Loading filter Regexskipdirs
DEBUG   |20260723 07:41:56|-- Loading filter Incremental
DEBUG   |20260723 07:41:56|-- Loading filter Regextables
DEBUG   |20260723 07:41:56|-- Loading filter Skipdirs
DEBUG   |20260723 07:41:56|-- Loading filter Files
DEBUG   |20260723 07:41:56|-- Loading filter Directories
DEBUG   |20260723 07:41:56|-- Loading filter Systemcachefiles
DEBUG   |20260723 07:41:56|-- Loading filter Excludetabledata
DEBUG   |20260723 07:41:56|-- Loading filter Excludefiles
DEBUG   |20260723 07:41:56|-- Loading filter Cvsfolders
DEBUG   |20260723 07:41:56|-- Loading filter Publicfolder
DEBUG   |20260723 07:41:56|-- Loading filter Joomlaskipfiles
DEBUG   |20260723 07:41:56|-- Loading filter Excludefolders
DEBUG   |20260723 07:41:56|-- Loading filter Siteroot
DEBUG   |20260723 07:41:56|-- Loading filter Libraries
DEBUG   |20260723 07:41:56|-- Loading filter Joomlaskipdirs
DEBUG   |20260723 07:41:56|-- Loading filter Sitedb
DEBUG   |20260723 07:41:56|Loading optional filters
DEBUG   |20260723 07:41:56|-- Loading optional filter Stack\StackHoststats
DEBUG   |20260723 07:41:56|-- Loading optional filter Stack\StackErrorlogs
DEBUG   |20260723 07:41:56|-- Loading optional filter Stack\StackActionlogs
DEBUG   |20260723 07:41:56|-- Loading optional filter Stack\StackFinder
DEBUG   |20260723 07:45:55|Fetching filter data from database
DEBUG   |20260723 07:45:55|Loading filters
DEBUG   |20260723 07:45:55|-- Loading filter Regexskipfiles
DEBUG   |20260723 07:45:55|-- Loading filter Multidb
DEBUG   |20260723 07:45:55|-- Loading filter Tables
DEBUG   |20260723 07:45:55|-- Loading filter Tabledata
DEBUG   |20260723 07:45:55|-- Loading filter Regexdirectories
DEBUG   |20260723 07:45:55|-- Loading filter Tablesalwaysskipped
DEBUG   |20260723 07:45:55|-- Loading filter Extradirs
DEBUG   |20260723 07:45:55|-- Loading filter Regexfiles
DEBUG   |20260723 07:45:55|-- Loading filter Regextabledata
DEBUG   |20260723 07:45:55|-- Loading filter Skipfiles
DEBUG   |20260723 07:45:55|-- Loading filter Regexskipdirs
DEBUG   |20260723 07:45:55|-- Loading filter Incremental
DEBUG   |20260723 07:45:55|-- Loading filter Regextables
DEBUG   |20260723 07:45:55|-- Loading filter Skipdirs
DEBUG   |20260723 07:45:55|-- Loading filter Files
DEBUG   |20260723 07:45:55|-- Loading filter Directories
DEBUG   |20260723 07:45:55|-- Loading filter Systemcachefiles
DEBUG   |20260723 07:45:55|-- Loading filter Excludetabledata
DEBUG   |20260723 07:45:55|-- Loading filter Excludefiles
DEBUG   |20260723 07:45:55|-- Loading filter Cvsfolders
DEBUG   |20260723 07:45:55|-- Loading filter Publicfolder
DEBUG   |20260723 07:45:55|-- Loading filter Joomlaskipfiles
DEBUG   |20260723 07:45:55|-- Loading filter Excludefolders
DEBUG   |20260723 07:45:55|-- Loading filter Siteroot
DEBUG   |20260723 07:45:55|-- Loading filter Libraries
DEBUG   |20260723 07:45:55|-- Loading filter Joomlaskipdirs
DEBUG   |20260723 07:45:55|-- Loading filter Sitedb
DEBUG   |20260723 07:45:55|Loading optional filters
DEBUG   |20260723 07:45:55|-- Loading optional filter Stack\StackHoststats
DEBUG   |20260723 07:45:55|-- Loading optional filter Stack\StackErrorlogs
DEBUG   |20260723 07:45:55|-- Loading optional filter Stack\StackActionlogs
DEBUG   |20260723 07:45:55|-- Loading optional filter Stack\StackFinder
